import setuptools

setuptools.setup(
	name='PyQwidgets',
	version='0.1.4',
	author='Georg8528',
	author_email='zadvornow2908@gmail.com',
	description='This mini-framework will help you create a widget!',
	packages=['PyQwidgets'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)